@@ -222,7 +222,8 @@ protected final class UnfoldedSubstring extends Substring {
 	 * @return String representation
 	 */
 	@Override
-	public String toString()
+	public String
+	toString()
 	{
 		return string;
 	}
@@ -257,7 +258,8 @@ protected final class AddrSpecSIDE extends Substring {
 	 * @return String representation (identical to the user data)
 	 */
 	@Override
-	public String toString()
+	public String
+	toString()
 	{
 		return (String)getData();
 	}
@@ -316,6 +318,7 @@ unfold(final Substring ss)
  *
  * @author mirabilos (t.glaser@tarent.de)
  */
+@SuppressWarnings("ProtectedMemberInFinalClass")
 @AllArgsConstructor
 private static final class Word {
 
@@ -746,7 +749,7 @@ pGroup()
 		final AddressList ml = pMailboxList();
 		if (ml == null)
 			pCFWS();
-		val gl = ml == null ? new ArrayList<Address>() : ml.addresses;
+		final List<Address> gl = ml == null ? new ArrayList<>() : ml.addresses;
 		// } [pGroupList]
 		if (cur() != ';')
 			return null;
@@ -1098,10 +1101,7 @@ pDomain()
 {
 	final Substring da = pDotAtom();
 	if (da != null) {
-		// dot-atom form of domain, does not need unfolding
-		final String us = da.toString();
-		boolean v = FQDN.isDomain(us);
-		return new AddrSpecSIDE(da, us, v);
+		return pDomainDotAtom(da);
 	}
 	final Substring dl = pDomainLiteral();
 	if (dl == null)
@@ -1121,6 +1121,15 @@ pDomain()
 	return new UnfoldedSubstring(dl, us, v);
 }
 
+protected AddrSpecSIDE
+pDomainDotAtom(final Substring da)
+{
+	// dot-atom form of domain, does not need unfolding
+	final String us = da.toString();
+	boolean v = FQDN.isDomain(us);
+	return new AddrSpecSIDE(da, us, v);
+}
+
 protected AddrSpec
 pAddrSpec()
 {
